@@ -55,7 +55,7 @@ class AddFeedDialog:
 				
 	def show(self, autolocation=True):
 		if utils.RUNNING_HILDON:
-			self._window.resize(600,200)
+			self._window.resize(650,300)
 			self._window.show_all()
 			
 		self._feed_url_widget.grab_focus()
@@ -145,7 +145,7 @@ class AddFeedDialog:
 		while gtk.events_pending(): #make sure the sensitivity change goes through
 			gtk.main_iteration()
 		try:
-			url,title = AddFeedUtils.correct_url(url, self._app.glade_prefix)
+			url,title = AddFeedUtils.correct_url(url, utils.get_glade_prefix())
 			if url is None:
 				if self._window:
 					self._window.set_sensitive(True)
